# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/).


## [Unreleased]
[Unreleased]: https://github.com/efficiosoft/hass_apps/compare/v0.20180205.0...HEAD

### Fixed

### Security

### Added

### Changed

### Deprecated

### Removed


## [0.20180205.0] - 2018-02-05
[0.20180205.0]: https://github.com/efficiosoft/hass_apps/compare/v0.20180203.0...v0.20180205.0

### Fixed
* Added missing release dates to CHANGELOG.md

### Added
* Added CHANGELOG.md and LICENSE to Python source package.
* Added appdaemon 3 support alongside the old appdaemon 2

### Changed
* heaty v0.10.0


## [0.20180203.0] - 2018-02-03
[0.20180203.0]: https://github.com/efficiosoft/hass_apps/compare/v0.20180202.1...v0.20180203.0

### Changed
* heaty v0.9.4


## [0.20180202.1] - 2018-02-02
[0.20180202.1]: https://github.com/efficiosoft/hass_apps/compare/v0.20180202.0...v0.20180202.1

### Changed
* heaty v0.9.3


## [0.20180202.0] - 2018-02-02
[0.20180202.0]: https://github.com/efficiosoft/hass_apps/compare/v0.20180201.0...v0.20180202.0

### Changed
* heaty v0.9.2


## 0.20180201.0 - 2018-02-01

### Added
- Begin using CHANGELOG.md
